# [License](../LICENSE)

# Install

## From latest source at PyPI

```bash
pip install --upgrade pyssword
```

## From latest source at git repo

```bash
pip install --upgrade https://gitlab.com/vassis/pyssword/-/archive/master/pyssword-master.tar.gz
```

# Usage

Find out by running the help command:

```bash
pyssword --help
```
